@@ -5,9 +5,9 @@ use warnings;
 package Exporter::Almighty;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001002';
+our $VERSION   = '0.001003';
 
-use parent           qw( Exporter::Tiny );
+use parent qw( Exporter::Tiny );
 
 my @builtins;
 BEGIN { @builtins = qw( is_bool created_as_string created_as_number ) };
@@ -57,19 +57,17 @@ sub standard_package_variables {
 }
 
 signature_for setup_for => (
-	method     => 1,
-	positional => [
-		NonEmptySimpleStr,
-		Dict[
-			tag    => Optional[HashRef],
-			also   => Optional[ArrayRef],
-			enum   => Optional[HashRef[ArrayRef]],
-			class  => Optional[ArrayRef],
-			role   => Optional[ArrayRef],
-			duck   => Optional[HashRef[ArrayRef]],
-			type   => Optional[ArrayRef],
-			const  => Optional[HashRef],
-		],
+	method  => 1,
+	head    => [ NonEmptySimpleStr ],
+	named   => [
+		tag    => Optional[HashRef],
+		also   => Optional[ArrayRef],
+		enum   => Optional[HashRef[ArrayRef]],
+		class  => Optional[ArrayRef],
+		role   => Optional[ArrayRef],
+		duck   => Optional[HashRef[ArrayRef]],
+		type   => Optional[ArrayRef],
+		const  => Optional[HashRef],
 	],
 );
 
@@ -343,6 +341,7 @@ Exporter::Almighty - combining Exporter::Tiny with some other stuff for added po
 
   package Your::Package;
   
+  use v5.12;
   use Exporter::Almighty -setup => {
     tag => {
       foo => [ 'foo1', 'foo2' ],
@@ -373,6 +372,14 @@ This module aims to make building exporters easier. It is based on
 L<Exporter::Tiny>, but helps you avoid manually setting C<< @EXPORT_OK >>,
 C<< %EXPORT_TAGS >>, etc.
 
+Exporter::Almighty supports lexical exports, even on Perl versions as old
+as 5.12.
+
+Exporter::Almighty indeed requires Perl 5.12, so it's strongly recommended
+you add C<< use v5.12 >> (or higher) before C<< use Exporter::Almighty >>
+so that your package can benefit from features which don't exist in legacy
+versions of Perl.
+
 =head2 Setup Options
 
 Exporter::Almighty's own setup happens through its import. A setup hashref
@@ -434,7 +441,7 @@ should be SHOUTING_SNAKE_CASE.
 
 This is an arrayref of type libraries. Each library listed will be I<imported>
 into your exporter, and then the types in it will be I<re-exported> to the
-people who use your caller. Each type library can optionally be followed by an
+people who use your package. Each type library can optionally be followed by an
 arrayref of type names if you don't want to just import all types.
 
   package Your::Package;
@@ -445,8 +452,8 @@ arrayref of type names if you don't want to just import all types.
     },
     type => [
       'Types::Standard',
-      'Types::Common::String' => [ 'NonEmptyStr' ],
-      'Types::Common::String' => [ 'PositiveInt', 'PositiveOrZeroInt' ],
+      'Types::Common::String'  => [ 'NonEmptyStr' ],
+      'Types::Common::Numeric' => [ 'PositiveInt', 'PositiveOrZeroInt' ],
     ],
   };
   
@@ -559,7 +566,7 @@ works. It will similarly promote your exporter to be a L<Type::Library>.
 =head3 C<< also >>
 
 A list of other packages to also export to your caller. Each package name
-can optionally be followed by an arrayerf of import arguments.
+can optionally be followed by an arrayref of import arguments.
 
   use Exporter::Almighty -setup => {
     also => [
@@ -583,7 +590,7 @@ Instead of:
 
 It is possible to do this at run-time:
 
-  Exporter::Almighty->setup_for( 'Your::Package', \%setup );
+  Exporter::Almighty->setup_for( 'Your::Package', %setup );
 
 This may allow slightly more flexibility in some cases.
 
@@ -593,6 +600,8 @@ Exporter::Almighty is also designed to be easily subclassable.
 
 =head3 Features for you
 
+Exporter::Almighty will import L<strict> and L<warnings> into your package.
+
 You can export package variables, though it's rarely a good idea:
 
   package Your::Package;
